Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(122)

Unified Diff: src/trusted/validator_mips/ncvalidate.h

Issue 10919162: [MIPS] Implementation of sel_ldr for MIPS architecture. (Closed) Base URL: http://src.chromium.org/native_client/trunk/src/native_client/
Patch Set: Rebase (Saturday morning). Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/trusted/validator_mips/cpuid_mips.h ('k') | src/trusted/validator_mips/ncvalidate.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/trusted/validator_mips/ncvalidate.h
diff --git a/src/trusted/validator_arm/ncvalidate.h b/src/trusted/validator_mips/ncvalidate.h
similarity index 52%
copy from src/trusted/validator_arm/ncvalidate.h
copy to src/trusted/validator_mips/ncvalidate.h
index a4a319ac63b700cf621a9d0aab2de72a45f756a0..9c511dfd966bbdd34ad6fe02225bd19c1a936982 100644
--- a/src/trusted/validator_arm/ncvalidate.h
+++ b/src/trusted/validator_mips/ncvalidate.h
@@ -1,12 +1,11 @@
/*
- * Copyright 2009 The Native Client Authors. All rights reserved.
+ * Copyright 2012 The Native Client Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can
* be found in the LICENSE file.
- * Copyright 2009, Google Inc.
*/
-#ifndef NATIVE_CLIENT_SRC_TRUSTED_VALIDATOR_ARM_V2_NCVALIDATE_H
-#define NATIVE_CLIENT_SRC_TRUSTED_VALIDATOR_ARM_V2_NCVALIDATE_H
+#ifndef NATIVE_CLIENT_SRC_TRUSTED_VALIDATOR_MIPS_NCVALIDATE_H
+#define NATIVE_CLIENT_SRC_TRUSTED_VALIDATOR_MIPS_NCVALIDATE_H
/*
* The C interface to the validator, for use by the sel_ldr (which isn't
@@ -24,13 +23,15 @@ EXTERN_C_BEGIN
/*
* Validates a complete code segment.
* Arguments:
* mbase location of the code in memory right now.
* vbase virtual address where the code will appear at runtime.
* size number of bytes of code provided.
* Result: 0 if validation succeeded, non-zero if we found problems.
*/
-int NCValidateSegment(uint8_t *mbase, uint32_t vbase, size_t size);
+int NCValidateSegment(uint8_t *mbase, uint32_t vbase, size_t size,
+ bool stubout_mode = false);
EXTERN_C_END
-#endif // NATIVE_CLIENT_SRC_TRUSTED_VALIDATOR_ARM_V2_NCVALIDATE_H
+#endif // NATIVE_CLIENT_SRC_TRUSTED_VALIDATOR_MIPS_NCVALIDATE_H
« no previous file with comments | « src/trusted/validator_mips/cpuid_mips.h ('k') | src/trusted/validator_mips/ncvalidate.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -24,13 +23,15 @@ EXTERN_C_BEGIN
* Validates a complete code segment.
* Arguments:
- * mbase location of the code in memory right now.
- * vbase virtual address where the code will appear at runtime.
- * size number of bytes of code provided.
+ * mbase location of the code in memory right now.
+ * vbase virtual address where the code will appear at runtime.
+ * size number of bytes of code provided.
+ * stubout_mode info if the validator should stub-out functions.
* Result: 0 if validation succeeded, non-zero if we found problems.
*/
This is Rietveld 408576698